@@ -103,7 +103,7 @@ namespace Beagle.Filters {
 			GMime.InternetAddressList addrs;
 			addrs = this.message.GetRecipients (GMime.Message.RecipientType.To);
 			foreach (GMime.InternetAddress ia in addrs) {
-				AddProperty (Property.NewKeyword ("fixme:to", ia.ToString (false)));
+				AddProperty (Property.NewUnsearched ("fixme:to", ia.ToString (false)));
 				if (ia.AddressType != GMime.InternetAddressType.Group) {
 					AddProperty (Property.New ("fixme:to_address", ia.Addr));
 					AddProperty (Property.NewUnstored ("fixme:to_sanitized", StringFu.SanitizeEmail (ia.Addr)));
@@ -114,7 +114,7 @@ namespace Beagle.Filters {
 
 			addrs = this.message.GetRecipients (GMime.Message.RecipientType.Cc);
 			foreach (GMime.InternetAddress ia in addrs) {
-				AddProperty (Property.NewKeyword ("fixme:cc", ia.ToString (false)));
+				AddProperty (Property.NewUnsearched ("fixme:cc", ia.ToString (false)));
 				if (ia.AddressType != GMime.InternetAddressType.Group) {
 					AddProperty (Property.New ("fixme:cc_address", ia.Addr));
 					AddProperty (Property.NewUnstored ("fixme:cc_sanitized", StringFu.SanitizeEmail (ia.Addr)));
@@ -125,7 +125,7 @@ namespace Beagle.Filters {
 
 			addrs = GMime.InternetAddressList.ParseString (GMime.Utils.HeaderDecodePhrase (this.message.Sender));
 			foreach (GMime.InternetAddress ia in addrs) {
-				AddProperty (Property.NewKeyword ("fixme:from", ia.ToString (false)));
+				AddProperty (Property.NewUnsearched ("fixme:from", ia.ToString (false)));
 				if (ia.AddressType != GMime.InternetAddressType.Group) {
 					AddProperty (Property.New ("fixme:from_address", ia.Addr));
 					AddProperty (Property.NewUnstored ("fixme:from_sanitized", StringFu.SanitizeEmail (ia.Addr)));
