@@ -38,12 +38,15 @@ namespace Beagle.Util {
 
 		static public DateTime GetLastWriteTimeUtc (string path)
 		{
+			if (path == null)
+				throw new ArgumentNullException ("path");
+
 			if (File.Exists (path))
 				return File.GetLastWriteTimeUtc (path);
 			else if (Directory.Exists (path))
 				return Directory.GetLastWriteTimeUtc (path);
 			else
-				throw new IOException (path);
+				throw new FileNotFoundException (path);
 		}
 
 		static public FileSystemInfo New (string path)
@@ -61,6 +64,16 @@ namespace Beagle.Util {
 			return (stat.st_mode & Mono.Unix.Native.FilePermissions.S_IFLNK) == Mono.Unix.Native.FilePermissions.S_IFLNK;
 		}
 
+		// Special version of this function which handles the root directory.
+		static public string GetDirectoryNameRootOk (string path)
+		{
+			// System.IO.Path.GetDirectoryName ("/") returns null.
+			// Handle it specially.
+			if (path == "/")
+				return path;
+
+			return System.IO.Path.GetDirectoryName (path);
+		}
 	}
 
 }
