@@ -41,9 +41,9 @@ namespace Beagle.Daemon.FileSystemQueryable {
 
 		static public bool Debug = false;
 
-		private const string SplitFilenamePropKey = "beagle:Filename";
+		private const string SplitFilenamePropKey = "beagle:SplitFilename";
 		public const string ExactFilenamePropKey = "beagle:ExactFilename";
-		public const string TextFilenamePropKey = "beagle:TextFilename";
+		public const string TextFilenamePropKey = "beagle:Filename";
 		public const string NoPunctFilenamePropKey = "beagle:NoPunctFilename";
 		public const string FilenameExtensionPropKey = "beagle:FilenameExtension";
 		public const string ParentDirUriPropKey = LuceneQueryingDriver.PrivateNamespace + "ParentDirUri";
@@ -53,7 +53,9 @@ namespace Beagle.Daemon.FileSystemQueryable {
 		// 1: Initially set to force a reindex due to NameIndex changes.
 		// 2: Overhauled everything to use new lucene infrastructure.
 		// 3: Switched to UTC for all times, changed the properties a bit.
-		const int MINOR_VERSION = 3;
+		// 4: Changed the key of TextFilenamePropKey to beagle:Filename - it might be useful in clients.
+		//    Make SplitFilenamePropKey unstored
+		const int MINOR_VERSION = 4;
 
 		private object big_lock = new object ();
 
@@ -167,13 +169,13 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			prop.IsMutable = mutable;
 			indexable.AddProperty (prop);
 
-			prop = Property.NewKeyword (FilenameExtensionPropKey, ext);
+			prop = Property.NewUnsearched (FilenameExtensionPropKey, ext);
 			prop.IsMutable = mutable;
 			indexable.AddProperty (prop);
 
 			string str;
 			str = StringFu.FuzzyDivide (no_ext);
-			prop = Property.New (SplitFilenamePropKey, str);
+			prop = Property.NewUnstored (SplitFilenamePropKey, str);
 			prop.IsMutable = mutable;
 			indexable.AddProperty (prop);
 
@@ -183,7 +185,7 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			str = GuidFu.ToUriString (parent_id);
 			// We use the uri here to recycle terms in the index,
 			// since each directory's uri will already be indexed.
-			prop = Property.NewKeyword (ParentDirUriPropKey, str);
+			prop = Property.NewUnsearched (ParentDirUriPropKey, str);
 			prop.IsMutable = mutable;
 			indexable.AddProperty (prop);
 		}
@@ -206,10 +208,15 @@ namespace Beagle.Daemon.FileSystemQueryable {
 							      DirectoryModel parent)
 		{
 			Indexable indexable;
-			indexable = new Indexable (IndexableType.Add, GuidFu.ToUri (id));
-			indexable.MimeType = "inode/directory";
-			indexable.NoContent = true;
-			indexable.Timestamp = Directory.GetLastWriteTimeUtc (path);
+			try {
+				indexable = new Indexable (IndexableType.Add, GuidFu.ToUri (id));
+				indexable.MimeType = "inode/directory";
+				indexable.NoContent = true;
+				indexable.Timestamp = Directory.GetLastWriteTimeUtc (path);
+			} catch (IOException) {
+				// Looks like the directory was deleted.
+				return null;
+			}
 
 			string name;
 			if (parent == null)
@@ -234,11 +241,17 @@ namespace Beagle.Daemon.FileSystemQueryable {
 							 bool           crawl_mode)
 		{
 			Indexable indexable;
-			indexable = new Indexable (IndexableType.Add, GuidFu.ToUri (id));
-			indexable.Timestamp = File.GetLastWriteTimeUtc (path);
-			indexable.ContentUri = UriFu.PathToFileUri (path);
-			indexable.Crawled = crawl_mode;
-			indexable.Filtering = Beagle.IndexableFiltering.Always;
+
+			try {
+				indexable = new Indexable (IndexableType.Add, GuidFu.ToUri (id));
+				indexable.Timestamp = File.GetLastWriteTimeUtc (path);
+				indexable.ContentUri = UriFu.PathToFileUri (path);
+				indexable.Crawled = crawl_mode;
+				indexable.Filtering = Beagle.IndexableFiltering.Always;
+			} catch (IOException) {
+				// Looks like the file was deleted.
+				return null;
+			}
 
 			AddStandardPropertiesToIndexable (indexable, Path.GetFileName (path), parent, true);
 
@@ -537,17 +550,19 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			Indexable indexable;
 			indexable = DirectoryToIndexable (path, id, parent);
 
-			indexable.LocalState ["Name"] = name;
-			indexable.LocalState ["LastCrawl"] = last_crawl;
-			indexable.LocalState ["IsWalkable"] = is_walkable;
+			if (indexable != null) {
+				indexable.LocalState ["Name"] = name;
+				indexable.LocalState ["LastCrawl"] = last_crawl;
+				indexable.LocalState ["IsWalkable"] = is_walkable;
 
-			Scheduler.Task task;
-			task = NewAddTask (indexable);
-			task.Priority = Scheduler.Priority.Delayed;
-			ThisScheduler.Add (task);
+				Scheduler.Task task;
+				task = NewAddTask (indexable);
+				task.Priority = Scheduler.Priority.Delayed;
+				ThisScheduler.Add (task);
+			}
 		}
 
-		private void RegisterDirectory (string name, DirectoryModel parent, FileAttributes attr)
+		private bool RegisterDirectory (string name, DirectoryModel parent, FileAttributes attr)
 		{
 			string path;
 			path = (parent == null) ? name : Path.Combine (parent.FullName, name);
@@ -555,13 +570,22 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			if (Debug)
 				Logger.Log.Debug ("Registered directory '{0}' ({1})", path, attr.UniqueId);
 
+			DateTime mtime;
+
+			try {
+				mtime = Directory.GetLastWriteTimeUtc (path);
+			} catch (IOException) {
+				Log.Debug ("Directory '{0}' ({1}) appears to have gone away", path, attr.UniqueId);
+				return false;
+			}
+
 			DirectoryModel dir;
 			if (parent == null)
 				dir = DirectoryModel.NewRoot (big_lock, path, attr);
 			else
 				dir = parent.AddChild (name, attr);
 
-			if (Directory.GetLastWriteTimeUtc (path) > attr.LastWriteTime) {
+			if (mtime > attr.LastWriteTime) {
 				dir.State = DirectoryState.Dirty;
 				if (Debug)
 					Logger.Log.Debug ("'{0}' is dirty", path);
@@ -593,6 +617,8 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			// Make sure that our file crawling task is active,
 			// since presumably we now have something new to crawl.
 			ActivateFileCrawling ();
+
+			return true;
 		}
 
 		private void ForgetDirectoryRecursively (DirectoryModel dir)
@@ -722,6 +748,10 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			FileAttributes attr;
 			attr = FileAttributesStore.Read (dir.FullName);
 
+			// Don't mark ourselves; let the crawler redo us
+			if (attr == null)
+				return;
+
 			// We don't have to be super-careful about this since
 			// we only use the FileAttributes mtime on a directory
 			// to determine its initial state, not whether or not
@@ -761,7 +791,7 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			bool path_is_registered = true;
 
 			if (dir == null) {
-				dir = GetDirectoryModelByPath (Path.GetDirectoryName (path));
+				dir = GetDirectoryModelByPath (FileSystem.GetDirectoryNameRootOk (path));
 				path_is_registered = false;
 
 				if (dir == null) {
@@ -1028,10 +1058,12 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			Indexable indexable;
 			indexable = FileToIndexable (path, unique_id, dir, false);
 
-			Scheduler.Task task;
-			task = NewAddTask (indexable);
-			task.Priority = Scheduler.Priority.Immediate;
-			ThisScheduler.Add (task);
+			if (indexable != null) {
+				Scheduler.Task task;
+				task = NewAddTask (indexable);
+				task.Priority = Scheduler.Priority.Immediate;
+				ThisScheduler.Add (task);
+			}
 		}
 
 		public void RemoveFile (DirectoryModel dir, string name)
@@ -1042,7 +1074,7 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			Guid unique_id;
 			unique_id = NameAndParentToId (name, dir);
 			if (unique_id == Guid.Empty) {
-				Logger.Log.Warn ("Could resolve unique id of '{0}' in '{1}' for removal, it is probably already gone",
+				Logger.Log.Info ("Could not resolve unique id of '{0}' in '{1}' for removal, it is probably already gone",
 						 name, dir.FullName);
 				return;
 			}
@@ -1224,7 +1256,8 @@ namespace Beagle.Daemon.FileSystemQueryable {
 				string name;
 				name = (string) indexable.LocalState ["Name"];
 
-				RegisterDirectory (name, parent, attr);
+				if (! RegisterDirectory (name, parent, attr))
+					return;
 			}
 
 			FileAttributesStore.Write (attr);
@@ -1249,7 +1282,7 @@ namespace Beagle.Daemon.FileSystemQueryable {
 		{
 			// Store the hit's internal uri in a property
 			Property prop;
-			prop = Property.NewKeyword ("beagle:InternalUri",
+			prop = Property.NewUnsearched ("beagle:InternalUri",
 						    UriFu.UriToSerializableString (hit.Uri));
 			hit.AddProperty (prop);
 
