@@ -281,11 +281,8 @@ namespace Beagle.Daemon {
 
 			if (change_data != null) {
 				
-				if (change_data.RemovedUris != null) {
-					foreach (Uri uri in change_data.RemovedUris)
-						Log.Debug ("Signalling removal of {0}", uri);
+				if (change_data.RemovedUris != null)
 					query_result.Subtract (change_data.RemovedUris);
-				}
 
 				// If nothing was added, we can safely return now: this change
 				// cannot have any further effect on an outstanding live query.
@@ -430,7 +427,7 @@ namespace Beagle.Daemon {
 		{
 			string path = Path.Combine (Path.Combine (PathFinder.IndexDir, this.IndexName), name);
 			
-			return new FileStream (path, System.IO.FileMode.Create, FileAccess.Write);
+			return new FileStream (path, System.IO.FileMode.Create, FileAccess.Write, FileShare.ReadWrite);
 		}
 
 		public void WriteDataLine (string name, string line)
@@ -554,6 +551,11 @@ namespace Beagle.Daemon {
 				QueryableState old_state = queryable.State;
 				queryable.State = QueryableState.Indexing;
 
+				// Number of times a null indexable was returned.  We don't want
+				// to spin tightly in a loop here if we're not actually indexing
+				// things.
+				int misfires = 0;
+
 				do {
 					if (! generator.HasNextIndexable ()) {
 						// ...except if there is no more work to do, of course.
@@ -568,11 +570,19 @@ namespace Beagle.Daemon {
 					// This means that the generator didn't have an indexable
 					// to return this time through, but it does not mean that
 					// its processing queue is empty.
-					if (generated == null)
-						continue;
+					if (generated == null) {
+						misfires++;
+
+						if (misfires > 179) // Another totally arbitrary number
+							break;
+						else
+							continue;
+					}
 
 					if (queryable.PreAddIndexableHook (generated))
 						queryable.AddIndexable (generated);
+					else
+						generated.Cleanup ();
 					
 					// We keep adding indexables until a flush goes through.
 				} while (! queryable.ConditionalFlush ());
@@ -945,6 +955,7 @@ namespace Beagle.Daemon {
 						if (please_add_a_new_task) {
 							//Logger.Log.Debug ("Adding child {0}", child.Uri);
 							Scheduler.Task task = NewAddTask (child);
+							task.SubPriority = 1;
 							ThisScheduler.Add (task);
 						} else
 							child.Cleanup ();
