@@ -67,7 +67,7 @@ namespace Beagle.Daemon {
 					XmlFu.SerializeUtf8 (serializer, mem_stream, new ResponseWrapper (response));
 					mem_stream.Seek (0, SeekOrigin.Begin);
 					StreamReader r = new StreamReader (mem_stream);
-					Logger.Log.Debug ("Sending response:\n{0}", r.ReadToEnd ());
+					Logger.Log.Debug ("Sending response:\n{0}\n", r.ReadToEnd ());
 					mem_stream.Seek (0, SeekOrigin.Begin);
 					mem_stream.WriteTo (this.client.GetStream ());
 					mem_stream.Close ();
@@ -226,6 +226,12 @@ namespace Beagle.Daemon {
 
 			buffer_stream.Seek (0, SeekOrigin.Begin);
 
+#if ENABLE_XML_DUMP
+			StreamReader r = new StreamReader (buffer_stream);
+			Logger.Log.Debug ("Received request:\n{0}\n", r.ReadToEnd ());
+			buffer_stream.Seek (0, SeekOrigin.Begin);
+#endif
+
 			try {
 				RequestWrapper wrapper = (RequestWrapper) req_serializer.Deserialize (buffer_stream);
 				
@@ -389,8 +395,10 @@ namespace Beagle.Daemon {
 
 		public void Stop ()
 		{
-			this.running = false;
-			this.listener.Stop ();
+			if (this.running) {
+				this.running = false;
+				this.listener.Stop ();
+			}
 			File.Delete (this.socket_path);
 		}
 
