@@ -261,8 +261,7 @@ namespace Search {
 			view.Sort = sort;
 			pages.CurrentPage = pages.PageNum (panes);
 
-			if (grabFocus)
-				oldFocus = Focus;
+			oldFocus = grabFocus ? Focus : null;
 
 			try {
 				if (currentQuery != null) {
@@ -352,6 +351,7 @@ namespace Search {
 				currentQuery.HitsAddedEvent -= OnHitsAdded;
 				currentQuery.HitsSubtractedEvent -= OnHitsSubtracted;
 				currentQuery.Close ();
+				currentQuery = null;
 			}
 
 			pages.CurrentPage = pages.PageNum (quicktips);
