@@ -138,8 +138,8 @@ class QueryTool {
 			"                    \t\ttype. Can be used multiply.\n" +
 			"  --source <source>\t\tConstrain query to the specified source.\n" +
 			"                   \t\tSources list available from beagle-status.\n" +
-			"  --start <date>\t\t\tConstrain query to items after specified date.\n" +
-			"                \t\t\tDate must be in the form \"yyyyMMdd\" or \"yyyyMMddHHmmss\"\n" +
+			"  --start <date>\t\tConstrain query to items after specified date.\n" +
+			"                \t\tDate must be in the form \"yyyyMMdd\" or \"yyyyMMddHHmmss\"\n" +
 			"  --end <date>\t\t\tConstrain query to items before specified date.\n" +
 			"              \t\t\tDate must be in the form \"yyyyMMdd\" or \"yyyyMMddHHmmss\"\n" +
 			"  --live-query\t\t\tRun continuously, printing notifications if a\n" +
@@ -258,6 +258,7 @@ class QueryTool {
 					Console.WriteLine ("Invalid start date");
 					System.Environment.Exit (-1);
 				}
+				start_date = start_date.ToUniversalTime ();
 				break;
 
 			case "--end":
@@ -270,12 +271,15 @@ class QueryTool {
 					Console.WriteLine ("Invalid end date");
 					System.Environment.Exit (-1);
 				}
+				end_date = end_date.ToUniversalTime ();
 				break;
 
 			default:
 				if (query_str.Length > 0)
 					query_str.Append (' ');
+				query_str.Append ('"');
 				query_str.Append (args [i]);
+				query_str.Append ('"');
 				break;
 			}
 
